# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pubsub.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cpubsub.proto\"\x1d\n\nSubRequest\x12\x0f\n\x07payload\x18\x01 \x01(\t\"\x1e\n\x0bSubResponse\x12\x0f\n\x07payload\x18\x01 \x01(\t\"\x1d\n\nPubRequest\x12\x0f\n\x07payload\x18\x01 \x01(\t\"\x1e\n\x0bPubResponse\x12\x0f\n\x07payload\x18\x01 \x01(\t2\x88\x01\n\x10PublisherService\x12\"\n\x03\x41\x64\x64\x12\x0b.SubRequest\x1a\x0c.SubResponse\"\x00\x12%\n\x06Remove\x12\x0b.SubRequest\x1a\x0c.SubResponse\"\x00\x12)\n\x06Notify\x12\x0b.SubRequest\x1a\x0c.SubResponse\"\x00(\x01\x30\x01\x32>\n\x11SubscriberService\x12)\n\x06Update\x12\x0b.PubRequest\x1a\x0c.PubResponse\"\x00(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pubsub_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SUBREQUEST']._serialized_start=16
  _globals['_SUBREQUEST']._serialized_end=45
  _globals['_SUBRESPONSE']._serialized_start=47
  _globals['_SUBRESPONSE']._serialized_end=77
  _globals['_PUBREQUEST']._serialized_start=79
  _globals['_PUBREQUEST']._serialized_end=108
  _globals['_PUBRESPONSE']._serialized_start=110
  _globals['_PUBRESPONSE']._serialized_end=140
  _globals['_PUBLISHERSERVICE']._serialized_start=143
  _globals['_PUBLISHERSERVICE']._serialized_end=279
  _globals['_SUBSCRIBERSERVICE']._serialized_start=281
  _globals['_SUBSCRIBERSERVICE']._serialized_end=343
# @@protoc_insertion_point(module_scope)



# GENERATED FILE DO NOT CHANGE !!!
import sys
from pathlib import Path
sys.path.append(str(Path(__file__).resolve().parent))
from connector_pb2 import *
from connector_pb2 import *
from connector_pb2_grpc import *
from pubsub_pb2 import *
from pubsub_pb2 import *
from pubsub_pb2_grpc import *



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import pubsub_pb2 as pubsub__pb2


class PublisherServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Add = channel.unary_unary(
                '/PublisherService/Add',
                request_serializer=pubsub__pb2.SubRequest.SerializeToString,
                response_deserializer=pubsub__pb2.SubResponse.FromString,
                )
        self.Remove = channel.unary_unary(
                '/PublisherService/Remove',
                request_serializer=pubsub__pb2.SubRequest.SerializeToString,
                response_deserializer=pubsub__pb2.SubResponse.FromString,
                )
        self.Notify = channel.stream_stream(
                '/PublisherService/Notify',
                request_serializer=pubsub__pb2.SubRequest.SerializeToString,
                response_deserializer=pubsub__pb2.SubResponse.FromString,
                )


class PublisherServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Add(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Remove(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Notify(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PublisherServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Add': grpc.unary_unary_rpc_method_handler(
                    servicer.Add,
                    request_deserializer=pubsub__pb2.SubRequest.FromString,
                    response_serializer=pubsub__pb2.SubResponse.SerializeToString,
            ),
            'Remove': grpc.unary_unary_rpc_method_handler(
                    servicer.Remove,
                    request_deserializer=pubsub__pb2.SubRequest.FromString,
                    response_serializer=pubsub__pb2.SubResponse.SerializeToString,
            ),
            'Notify': grpc.stream_stream_rpc_method_handler(
                    servicer.Notify,
                    request_deserializer=pubsub__pb2.SubRequest.FromString,
                    response_serializer=pubsub__pb2.SubResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'PublisherService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PublisherService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Add(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/PublisherService/Add',
            pubsub__pb2.SubRequest.SerializeToString,
            pubsub__pb2.SubResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Remove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/PublisherService/Remove',
            pubsub__pb2.SubRequest.SerializeToString,
            pubsub__pb2.SubResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Notify(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/PublisherService/Notify',
            pubsub__pb2.SubRequest.SerializeToString,
            pubsub__pb2.SubResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class SubscriberServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Update = channel.stream_stream(
                '/SubscriberService/Update',
                request_serializer=pubsub__pb2.PubRequest.SerializeToString,
                response_deserializer=pubsub__pb2.PubResponse.FromString,
                )


class SubscriberServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Update(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SubscriberServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Update': grpc.stream_stream_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=pubsub__pb2.PubRequest.FromString,
                    response_serializer=pubsub__pb2.PubResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'SubscriberService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SubscriberService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Update(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/SubscriberService/Update',
            pubsub__pb2.PubRequest.SerializeToString,
            pubsub__pb2.PubResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NullValue(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    NULL_VALUE: _ClassVar[NullValue]
NULL_VALUE: NullValue

class DispatcherRequest(_message.Message):
    __slots__ = ["payload"]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    payload: ListValue
    def __init__(self, payload: _Optional[_Union[ListValue, _Mapping]] = ...) -> None: ...

class DispatcherResponse(_message.Message):
    __slots__ = ["payload"]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    payload: ListValue
    def __init__(self, payload: _Optional[_Union[ListValue, _Mapping]] = ...) -> None: ...

class Struct(_message.Message):
    __slots__ = ["fields"]
    class FieldsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: Value
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Value, _Mapping]] = ...) -> None: ...
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    fields: _containers.MessageMap[str, Value]
    def __init__(self, fields: _Optional[_Mapping[str, Value]] = ...) -> None: ...

class Value(_message.Message):
    __slots__ = ["null_value", "number_value", "string_value", "bool_value", "struct_value", "list_value"]
    NULL_VALUE_FIELD_NUMBER: _ClassVar[int]
    NUMBER_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUE_FIELD_NUMBER: _ClassVar[int]
    BOOL_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRUCT_VALUE_FIELD_NUMBER: _ClassVar[int]
    LIST_VALUE_FIELD_NUMBER: _ClassVar[int]
    null_value: NullValue
    number_value: float
    string_value: str
    bool_value: bool
    struct_value: Struct
    list_value: ListValue
    def __init__(self, null_value: _Optional[_Union[NullValue, str]] = ..., number_value: _Optional[float] = ..., string_value: _Optional[str] = ..., bool_value: bool = ..., struct_value: _Optional[_Union[Struct, _Mapping]] = ..., list_value: _Optional[_Union[ListValue, _Mapping]] = ...) -> None: ...

class ListValue(_message.Message):
    __slots__ = ["values"]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    values: _containers.RepeatedCompositeFieldContainer[Value]
    def __init__(self, values: _Optional[_Iterable[_Union[Value, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: connector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63onnector.proto\x1a\x19google/protobuf/any.proto\"0\n\x11\x44ispatcherRequest\x12\x1b\n\x07payload\x18\x01 \x01(\x0b\x32\n.ListValue\"1\n\x12\x44ispatcherResponse\x12\x1b\n\x07payload\x18\x01 \x01(\x0b\x32\n.ListValue\"d\n\x06Struct\x12#\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x13.Struct.FieldsEntry\x1a\x35\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x15\n\x05value\x18\x02 \x01(\x0b\x32\x06.Value:\x02\x38\x01\"\xba\x01\n\x05Value\x12 \n\nnull_value\x18\x01 \x01(\x0e\x32\n.NullValueH\x00\x12\x16\n\x0cnumber_value\x18\x02 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x03 \x01(\tH\x00\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x12\x1f\n\x0cstruct_value\x18\x05 \x01(\x0b\x32\x07.StructH\x00\x12 \n\nlist_value\x18\x06 \x01(\x0b\x32\n.ListValueH\x00\x42\x06\n\x04kind\"#\n\tListValue\x12\x16\n\x06values\x18\x01 \x03(\x0b\x32\x06.Value*\x1b\n\tNullValue\x12\x0e\n\nNULL_VALUE\x10\x00\x32K\n\x10\x43onnectorService\x12\x37\n\nDispatcher\x12\x12.DispatcherRequest\x1a\x13.DispatcherResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'connector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STRUCT_FIELDSENTRY._options = None
  _STRUCT_FIELDSENTRY._serialized_options = b'8\001'
  _globals['_NULLVALUE']._serialized_start=475
  _globals['_NULLVALUE']._serialized_end=502
  _globals['_DISPATCHERREQUEST']._serialized_start=46
  _globals['_DISPATCHERREQUEST']._serialized_end=94
  _globals['_DISPATCHERRESPONSE']._serialized_start=96
  _globals['_DISPATCHERRESPONSE']._serialized_end=145
  _globals['_STRUCT']._serialized_start=147
  _globals['_STRUCT']._serialized_end=247
  _globals['_STRUCT_FIELDSENTRY']._serialized_start=194
  _globals['_STRUCT_FIELDSENTRY']._serialized_end=247
  _globals['_VALUE']._serialized_start=250
  _globals['_VALUE']._serialized_end=436
  _globals['_LISTVALUE']._serialized_start=438
  _globals['_LISTVALUE']._serialized_end=473
  _globals['_CONNECTORSERVICE']._serialized_start=504
  _globals['_CONNECTORSERVICE']._serialized_end=579
# @@protoc_insertion_point(module_scope)
